@@ -7,7 +7,7 @@ package Circle::Net::IRC;
 use strict;
 use warnings;
 
-use base qw( Tangence::Object Circle::WindowItem Circle::Ruleable );
+use base qw( Circle::Net Circle::Ruleable );
 __PACKAGE__->APPLY_Ruleable;
 
 use base qw( Circle::Rule::Store ); # for the attributes
@@ -24,7 +24,7 @@ use Circle::Rule::Store;
 use Circle::Widget::Box;
 use Circle::Widget::Label;
 
-use Net::Async::IRC 0.09; # IaStream subclass
+use Net::Async::IRC 0.10; # on_irc_error
 use IO::Async::Timer::Countdown;
 
 use Text::Balanced qw( extract_delimited );
@@ -54,6 +54,12 @@ sub new
          $self->on_closed;
       },
 
+      on_irc_error => sub {
+         my ( $irc, $message ) = @_;
+         $self->push_displayevent( "status", { text => "IRC error $message" } );
+         $self->close_now;
+      },
+
       encoding => "UTF-8",
 
       pingtime => 120,
@@ -121,19 +127,6 @@ sub reify
    # always real; this is a no-op
 }
 
-sub set_network_status
-{
-   my $self = shift;
-   my ( $status ) = @_;
-
-   $self->{status} = $status;
-
-   my $text = $self->get_prop_tag;
-   $text .= "[$self->{status}]" if length $self->{status};
-
-   $self->{widget_netname}->set_prop_text( $text ) if $self->{widget_netname};
-}
-
 sub get_channel_if_exists
 {
    my $self = shift;
@@ -927,7 +920,6 @@ sub reconnect
       user => $s->{user},
       pass => $s->{pass},
       SSL  => $s->{SSL},
-      on_error => sub { warn "TODO: Empty closure" },
    );
 
    $f->on_fail( sub { $self->enqueue_reconnect } );
@@ -963,6 +955,34 @@ sub method_get_isupport
    return $irc->isupport( $key );
 }
 
+sub do_join
+{
+   my $self = shift;
+   my ( $channel, $key ) = @_;
+
+   my $pending = $self->{pending_joins} //= [];
+
+   if( !@$pending ) {
+      my $irc = $self->{irc};
+      $self->{loop}->later( sub {
+         my $channels = join ",", map { $_->[0] } @$pending;
+         my $keys     = join ",", map { defined $_->[1] ? ( $_->[1] ) : () } @$pending;
+
+         $irc->send_message( "JOIN", undef, $channels, length $keys ? ( $keys ) : () );
+
+         @$pending = ();
+      });
+   }
+
+   # Enqueue keyed joins first, others last
+   if( defined $key ) {
+      unshift @$pending, [ $channel, $key ];
+   }
+   else {
+      push @$pending, [ $channel ];
+   }
+}
+
 use Circle::Collection
    name  => 'servers',
    storage => 'array',
@@ -1347,7 +1367,13 @@ sub channels_add
 sub channels_del
 {
    my $self = shift;
-   die "TODO: delete channel @_\n";
+   my ( $name, $def ) = @_;
+
+   my $chanobj = $self->get_channel_if_exists( $name ) or return undef;
+
+   die "channel is joined" if $chanobj->{state} == Circle::Net::IRC::Channel::STATE_JOINED;
+
+   $chanobj->destroy;
 }
 
 sub commandable_parent
@@ -1452,28 +1478,6 @@ sub get_widget_statusbar
    return $statusbar;
 }
 
-sub get_widget_netname
-{
-   my $self = shift;
-
-   return $self->{widget_netname} ||= do {
-      my $registry = $self->{registry};
-
-      my $widget = $registry->construct(
-         "Circle::Widget::Label",
-         classes => [qw( netname )],
-      );
-      $self->watch_property( "tag",
-         on_updated => sub {
-            my $text = $_[1];
-            $text .= "[$self->{status}]" if length $self->{status};
-            $widget->set_prop_text( $text );
-         }
-      );
-      $widget;
-   };
-}
-
 sub get_widget_channel_completegroup
 {
    my $self = shift;
