@@ -77,8 +77,8 @@ sub join
 
    my $key = $args{key} // $self->{key};
 
-   my $irc = $self->{irc};
-   $irc->send_message( "JOIN", undef, $self->get_prop_name, defined $key ? ( $key ) : () );
+   my $net = $self->{net};
+   $net->do_join( $self->get_prop_name, $key );
 
    $self->{on_joined} = $on_joined;
    $self->{on_join_error} = $args{on_join_error};
