@@ -133,4 +133,4 @@ sub run
    }
 }
 
-1;
+0x55AA;
