@@ -194,6 +194,18 @@ sub method_get_widget
    return $self->{widget} ||= $self->make_widget();
 }
 
+# Useful for debugging and live-development
+sub command_rewidget
+   : Command_description("Destroy the cached widget tree so it will be recreated")
+{
+   my $self = shift;
+
+   delete $self->{widget};
+   $self->respond( "Destroyed existing widget tree. You will have to restart the frontend now" );
+
+   return;
+}
+
 # Subclasses might override this, but we'll provide a default
 sub make_widget
 {
